#!/usr/bin/perl
#
# Name:  binary_search/runtest.pl
#
# Copyright (c) 2009, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# LLNL-CODE-416230
# All rights reserved.
#
# This file is part of the Data-Intensive Benchmark Suite.
# Please read the COPYRIGHT, LICENSE, and NOTICE files that came with this
# distribution.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by
# the Free Software Foundation) version 2.1 dated February 1999.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
# conditions of the GNU Lesser General Public License for more details.
#
# You should have recieved a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

#  Vector size notes:
#  - Assume that input is 64M (2^26) vectors of length 32 (Vbytes=128, Totbytes=8GB)
#
#  How big should index cache be so only one page fetched?
#  - We can fit 32 (2^5) vectors in one 4KB page
#  - implies indexing is about 2M (2^26/2^5 = 2^21) vectors
#  - implies indexing cache should be at most 256MB
#
#  How many test vectors should we do?
#  - 1M (10^6) searches @  50e-6 seek time =   50s
#  - 1M (10^6) searches @  10e-3 seek time = 1000s
#  - 1k (10^3) ==> 50e-3s and 1s
#  - so 100k should give a medium test

require '../microbenchmark_globals.pl';


$num_input_vects = "64k";
$index_bytes     = "128m";
@num_threads = (1,2,4,8,16,32);


$fn_results = "./results_binary_search.csv";


genMissingBigFileData();       #build the missing files
genMissingSortedBigFileData(); #build a sorted file if needed


unlink $fn_results;


#Dump a header for the table that lists what the columns are for
system( ("./binary_search -Q -X > $fn_results") );

$bad_runs = 0;

foreach (@storage_dirs){
  $file_base = $_;

  foreach (@num_threads){
    $t = $_;

    system(@clear_cache_cmd) if($clear_cache);

    my @tst_cmd = ("./binary_search " .
		   "   -t $t -T $t " .                          # single thread number
		   "   -b $index_bytes  -B $index_bytes " .     # single index buffer size
		   "   -n $num_input_vects " .                  # limit number of input vectors
		   "   -C " .                                   # cache cleared above
		   "   -q " .                                   # tabular output
		   "   -u $file_base/$big_file_name " .
		   "      $file_base/sorted_$big_file_name   >> $fn_results");
    print "@tst_cmd\n";
    $foo = system(@tst_cmd);
    if($foo){
      print "Program exited with error code $foo\n";
      $bad_runs++;
    }
	
	
  }
}

print "Total instances of failed return codes: $bad_runs\n";




