/**
 * Name:  lists.h
 *
 * Copyright (c) 2009, Lawrence Livermore National Security, LLC.
 * Produced at the Lawrence Livermore National Laboratory.
 * LLNL-CODE-416230
 * All rights reserved.
 *
 * This file is part of the Data-Intensive Benchmark Suite.
 * Please read the COPYRIGHT, LICENSE, and NOTICE files that came with this
 * distribution.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License (as published by
 * the Free Software Foundation) version 2.1 dated February 1999.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
 * conditions of the GNU Lesser General Public License for more details.
 *
 * You should have recieved a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef LISTS_H
#define LISTS_H

// Functions for managing a set of list datastructures


typedef struct bestList_s {
  FILE   *f;            //The file we're working with
  int     thid;         //Our thread id (mt code only)
  u64     start_spot;   //id of vector to start with
  u64     num_spots;    //How many vectors to check
  int     k;            //How many vectors we're tracking
  int     vlen;         //How long the vectors are
  float  *searchVector; //Vector that we want to find a match for
  u64    *ids;          //ids of the best vectors
  float  *distances;    //What the distances were for these vectors
  float **matches;      //Actual data for the vectors we've found
  int     is_last;      //Marker saying this is the last input in this thread
} bestList_t;

bestList_t * createBestList(int k, int len);
void deleteBestList(bestList_t *a);
void resetBestList(bestList_t *b);

void mergeBestList(bestList_t *a, bestList_t *b);
int compareVectors(float *a, u64 id, bestList_t *best);

void dumpBest(bestList_t *b);

#endif
