#
# This file specifies globals for running the tests
#
# Name:  microbenchmark_globals.pl
#
# Copyright (c) 2009, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# LLNL-CODE-416230
# All rights reserved.
#
# This file is part of the Data-Intensive Benchmark Suite.
# Please read the COPYRIGHT, LICENSE, and NOTICE files that came with this
# distribution.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by
# the Free Software Foundation) version 2.1 dated February 1999.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
# conditions of the GNU Lesser General Public License for more details.
#
# You should have recieved a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

use File::Copy;

$clear_cache = 1;     # Non-zero means clear the disk cache between runs
$max_bytes   = "2g";  # Some tests allow you to limit how big the tests are

$big_file_components = "32"; # How many components are in each vector
$big_file_vectors    = "64m"; # How many vectors are in file. Use k,m,g for 10^3, 10^6, 10^9


@clear_cache_cmd = ("../tools/flushCache"); # Command used to clear disk cache

@storage_dirs = (
   "/tmp" #,
   #"/fusion1/ulmer1",
   #"/scratch/ulmer1"
);




#Things generate from the above globals


$big_file_name   = $big_file_components . "x" . $big_file_vectors . ".dat"; #ex: 32x64m.dat
$sorted_file_name = "sorted_$big_file_name";                                #ex: sorted_32x64m.dat


#==============================================================================
sub genMissingBigFileData {

  #make sure there's a file waiting for us on all directories
  my $missing_count=0;
  my $found = "";

  #see if the file is available everywhere
  foreach(@storage_dirs){
    if(!(-e "$_/$big_file_name")){
      $missing_count++;
    } else {
      $found = "$_/$big_file_name" if(!$found);
    }
  }
  return if(!$missing_count); #all there

  #generate the file if none already available
  if(!$found){
    my $first_dir = $storage_dirs[0];
    print "Generating unsorted vector file (this may take a while)\n";
    system(("../tools/genVectorData "   .
	    " -l $big_file_components " .
	    " -n $big_file_vectors "    .
	    " $first_dir/$big_file_name")         );

    $found = "$first_dir/$big_file_name";
  }
  if(!(-e $found)){ die "Problem finding big file '$found'\n"; }

  #scan through and copy file to missing points
  foreach(@storage_dirs){
    next if(-e "$_/$big_file_name");
    copy($found, "$_/$big_file_name") or die "Couldn't copy '$found' to '$_/$big_file_name'\n";
  }

}

#==============================================================================
sub genMissingSortedBigFileData {
  my $missing_count=0;
  my $found = "";

  #find which locations have the file
  foreach(@storage_dirs){
    if(!(-e "$_/$sorted_file_name")){
      $missing_count++;
    } else {
      $found = "$_/$sorted_file_name" if (!$found);
    }
  }
  return if(!$missing_count); #all there

  if(!$found){
    my $first_dir = $storage_dirs[0];
    print "Generating sorted file (this may take a while)\n";
    system(("../sort/sort_mt -t 2 -b 512m -p -C -i $first_dir/$big_file_name -m $first_dir/tmp_ -o $first_dir/$sorted_file_name"));
    $found = "$first_dir/$sorted_file_name";
  }
  if(!(-e $found)) { die "Problem finding sorted file '$found'\n"; }

  #scan through and copy file to missing points
  foreach(@storage_dirs){
    next if(-e "$_/$sorted_file_name");
    copy($found, "$_/$sorted_file_name") or die "Couldn't copy '$found' to '$_/$sorted_file_name'\n";
  }

}

1;
