/**
 * Name:  dumpFile.c
 *
 * Copyright (c) 2009, Lawrence Livermore National Security, LLC.
 * Produced at the Lawrence Livermore National Laboratory.
 * LLNL-CODE-416230
 * All rights reserved.
 *
 * This file is part of the Data-Intensive Benchmark Suite.
 * Please read the COPYRIGHT, LICENSE, and NOTICE files that came with this
 * distribution.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License (as published by
 * the Free Software Foundation) version 2.1 dated February 1999.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
 * conditions of the GNU Lesser General Public License for more details.
 *
 * You should have recieved a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#define _LARGEFILE64_SOURCE
#define _FILE_OFFSET_BITS 64

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <string.h>
#include <assert.h>

#include "common.h"

//=============================================================================
void dumpHelp(void){
  printf("\n"
	 "dumpFile <options> binary_file\n"
	 "    -r vnum : display the first vnum vectors on dump\n"
	 "    -c hnum : display the first hnum components of vectors on dump\n"
	 "\n");
  exit(0);
}

//=============================================================================
int main(int argc, char **argv){

  u64 i,ich;
  char *fn=NULL;
  
  u64  hlimit=0;
  u64  vlimit=0;

  //Pick off the switches/one args
  while( (ich=getopt(argc, argv, "r:c:h"))!=EOF){
    switch(ich){
    case 'r': vlimit = atoiUnits(optarg); break;
    case 'c': hlimit = atoiUnits(optarg); break;
    case 'h':
    default:
      dumpHelp();
      exit(0);
    }
  }

  if(optind == argc){
    printf("Missing input file\n\n");
    dumpHelp();
    exit(0);
  }

  fn = strdup(argv[optind]);

  dumpFile(fn, hlimit,vlimit);

}
