/**
 * Name:  reduceFile.c
 *
 * Copyright (c) 2009, Lawrence Livermore National Security, LLC.
 * Produced at the Lawrence Livermore National Laboratory.
 * LLNL-CODE-416230
 * All rights reserved.
 *
 * This file is part of the Data-Intensive Benchmark Suite.
 * Please read the COPYRIGHT, LICENSE, and NOTICE files that came with this
 * distribution.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License (as published by
 * the Free Software Foundation) version 2.1 dated February 1999.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
 * conditions of the GNU Lesser General Public License for more details.
 *
 * You should have recieved a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#define _LARGEFILE64_SOURCE
#define _FILE_OFFSET_BITS 64

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <string.h>

#include "common.h"



void dumpHelp(void){

  printf("\n"
	 "reduceFile [-p percent] <-r -R> -i input_filename -o output_filename\n"
	 "     -p percent  :  Scale by percentage (1-99)\n"
	 "     -r          :  Select vectors randomly\n"
	 "     -R          :  Select vectors by in-order decimation (ie, keep every nth vector)\n"
	 "\n");

  exit(0);

}

int main(int argc, char **argv){

  u64 i,ich,j;

  char *filename_i=NULL;
  char *filename_o=NULL;
  int pval=10;
  double fraction;
  int use_random=0;



  //Pick off the switches/one args
  while( (ich=getopt(argc, argv, "p:i:o:rRh"))!=EOF){
    switch(ich){
    case 'p': pval = atoi(optarg); break;
    case 'i': filename_i = strdup(optarg); break;
    case 'o': filename_o = strdup(optarg); break;
    case 'r': use_random=1; break;
    case 'R': use_random=0; break;    
    case 'h':
    default:
      dumpHelp();
      exit(0);
    }
  }
    //Anything else tagged on at end
  if((optind < argc)||(pval<1) || (pval>99) || (!filename_i) || (!filename_o))
    dumpHelp();

  seedRand();
  fraction = ((double)pval)/100.0;

  createReducedFile(filename_o, filename_i, fraction, use_random);
  
  return 0;
}
